
If you are already running 3rd party app which uses an Export.lua file then you will
need to incorporate the following code snippets into your existing Export.lua file.

If you do not already have an active Export.lua file then copy the one in this folder
to your Saved Games/DCS/Scripts folder (- usually in UserName/SavedGames). The required
code changes are included in the file.

For DCS to connect to the motion software the IPAddress and PostS parameters must be set
correctly in the Export.lua file and in your .bff config file. 

The BFF Motion Software must be running BEFORE the flight is made active. This is to ensure that
the motion software TCP server is up and running BEFORE DCS attempts to connect to it via the
LuaExportStart() function call in the Exports.lua file.





LUA code snippet to incorporate into your existing LuaExportStart() function code


--********************************
-- BFF LuaExportStart() mods for BFF 6DOF motion software
--********************************
--
--If the paths below have already been set in your LuaExportStart() section then they
--do not need to be uncommented here
   package.path  = package.path..";"..lfs.currentdir().."/LuaSocket/?.lua"
   package.cpath = package.cpath..";"..lfs.currentdir().."/LuaSocket/?.dll"
--Similarly if TCP socket code is already active in your Export.lua file then the line below may not need to be uncommented
   socket = require("socket")
   
--Set explicit host & port for connecting as a client to the BFF Motion Software TCP server
--These should match the IPAddress and PortS settings in your .bff config file
   IPAddress = "127.0.0.1"
   PortS = 48001
--Connect to the BFF TCP server 
   BFF_c = socket.try(socket.connect(IPAddress, PortS)) -- connect as client to the BFF server
   BFF_c:setoption("tcp-nodelay",true) -- set immediate transmission mode
--Set index counter for data packets
   BFF_Index = 0
--********************************
-- End of BFF mods
--********************************





LUA code snippet to incorporate into your existing LuaExportAfterNextFrame() function code

   
--********************************
-- BFF LuaExportAfterNextFrame() mods for BFF 6DOF motion software
--********************************
   BFF_Index = BFF_Index + 1
   local BFF_time = LoGetModelTime()
   local BFF_velocity = LoGetVectorVelocity()
   local BFF_Accel = LoGetAccelerationUnits()
   local BFF_Pitch, BFF_Bank, BFF_Yaw = LoGetADIPitchBankYaw()
   local BFF_RotVel = LoGetAngularVelocity()
   local BFF_VertVel = LoGetVerticalVelocity()
   local BFF_Height = LoGetAltitudeAboveGroundLevel()
   -- Send out fixed length 220 byte packet
   socket.try(BFF_c:send(string.format("%10i, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f, %12.4f", BFF_Index, BFF_time, BFF_velocity.x, BFF_velocity.y, BFF_velocity.z, BFF_Accel.x, BFF_Accel.y, BFF_Accel.z, BFF_Pitch, BFF_Bank, BFF_Yaw, BFF_RotVel.x, BFF_RotVel.y, BFF_RotVel.z, BFF_VertVel, BFF_Height)))
--********************************
-- End of BFF mods
--********************************





LUA code snippet to incorporate into your existing LuaExportStop() function code

   
--********************************
-- BFF LuaExportStop() mods for BFF 6DOF motion software
--********************************
   if BFF_c then 
      socket.try(BFF_c:send("quit")) -- to close the listener socket
      BFF_c:close()
   end
--********************************
-- End of BFF mods
--********************************


